import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import {
  SessionContextProvider,
  useSession,
} from "@supabase/auth-helpers-react";
import { supabase } from "@/integrations/supabase/client";
import { Suspense, lazy } from "react";
import { WhatsAppButton } from "./components/WhatsAppButton";

// Lazy load components for better performance
const Home = lazy(() => import("./pages/Home"));
const Admin = lazy(() => import("./pages/Admin"));
const Login = lazy(() => import("./pages/Login"));
const Contact = lazy(() => import("./pages/Contact"));
const Products = lazy(() => import("./pages/Products"));
const Membership = lazy(() => import("./pages/Membership"));
const ProductDetail = lazy(() => import("./pages/ProductDetail"));
const EyeCheckPage = lazy(() => import("./pages/EyeCheck"));
const LuckyAngpau = lazy(() => import("./pages/LuckyAngpau"));
const KelapaDua = lazy(() => import("./pages/KelpaDua"));

// Loading component for suspense fallbacks
const PageLoader = () => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary"></div>
  </div>
);

// Create a client with optimized settings for performance
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      retry: 1,
      refetchOnWindowFocus: false,
      staleTime: 5 * 60 * 1000, // 5 minutes
      gcTime: 10 * 60 * 1000, // 10 minutes (formerly cacheTime)
      refetchOnMount: false,
      refetchOnReconnect: false,
    },
    mutations: {
      retry: 1,
    },
  },
});

// Protected Route wrapper component
const ProtectedRoute = ({ children }: { children: React.ReactNode }) => {
  const session = useSession();

  if (!session) {
    window.location.href = "/login";
    return null;
  }

  return <>{children}</>;
};

const isAdminSubdomain = window.location.hostname.startsWith("admin.");

const App = () => {
  return (
    <QueryClientProvider client={queryClient}>
      <SessionContextProvider supabaseClient={supabase}>
        <TooltipProvider>
          <Toaster />
          <Sonner />
          <BrowserRouter>
            <Suspense fallback={<PageLoader />}>
              <Routes>
                {isAdminSubdomain ? (
                  // Admin subdomain routes
                  <>
                    <Route path="/login" element={<Login />} />
                    <Route
                      path="/"
                      element={
                        <ProtectedRoute>
                          <Admin />
                        </ProtectedRoute>
                      }
                    />
                    <Route path="*" element={<Navigate to="/" />} />
                  </>
                ) : (
                  // Main site routes
                  <>
                    <Route path="/" element={<Home />} />
                    <Route path="/store" element={<Home />} />
                    <Route path="/admin" element={<Admin />} />
                    <Route path="/login" element={<Login />} />
                    <Route path="/contact" element={<Contact />} />
                    <Route path="/products" element={<Products />} />
                    <Route path="/products/:id" element={<ProductDetail />} />
                    <Route
                      path="/products/:id/:slug"
                      element={<ProductDetail />}
                    />
                    <Route path="/membership" element={<Membership />} />
                    <Route path="/luckyangpao" element={<LuckyAngpau />} />
                    <Route path="/visiontest" element={<EyeCheckPage />} />
                    <Route path="/kelapadua" element={<KelapaDua />} />
                  </>
                )}
              </Routes>
            </Suspense>
            {!isAdminSubdomain && <WhatsAppButton />}
          </BrowserRouter>
        </TooltipProvider>
      </SessionContextProvider>
    </QueryClientProvider>
  );
};

export default App;
